oss-api-client 1.1.7

A Rust-based object storage service system that provides functionalities similar to Alibaba Cloud OSS. Supports file upload, download, preview, bucket management and more, using Axum as the web framework and SeaORM as the database ORM.
docs.rs failed to build oss-api-client-1.1.7
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: oss-api-client-1.5.0

oss-rs-api

这是 oss-rs 项目的 API 定义部分,包含了以下模块:

  • api: API 接口定义
  • dto: 数据传输对象
  • vo: 视图对象